@@ -13,13 +13,13 @@ class ScreenRect:
         y = self.size[1] / self.current_h
 
         self.vertices = (
-            -x + offset[0],  y + offset[1],    0.0, 1.0, 0.0, 0.0,    0.0, 1.0,
-             x + offset[0],  y + offset[1],    0.0, 1.0, 0.0, 0.0,    1.0, 1.0,
-            -x + offset[0], -y + offset[1],    0.0,1.0, 0.0, 0.0,     0.0, 0.0,
+            -x + offset[0],  y + offset[1],        0.0, 1.0,
+             x + offset[0],  y + offset[1],        1.0, 1.0,
+            -x + offset[0], -y + offset[1],        0.0, 0.0,
 
-           -x + offset[0], -y + offset[1],     0.0,1.0, 0.0, 0.0,      0.0, 0.0,
-           x + offset[0],  y + offset[1],      0.0,1.0, 0.0, 0.0,       1.0, 1.0,
-           x + offset[0], -y + offset[1],      0.0,1.0, 0.0, 0.0,       1.0, 0.0,
+           -x + offset[0], -y + offset[1],         0.0, 0.0,
+           x + offset[0],  y + offset[1],          1.0, 1.0,
+           x + offset[0], -y + offset[1],          1.0, 0.0,
         )
 
         self.vertices = np.array(self.vertices, dtype=np.float32)
